# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from keplar_api.models.screener_question_choose_multiple_options_value import ScreenerQuestionChooseMultipleOptionsValue
from typing import Optional, Set
from typing_extensions import Self

class ScreenerQuestionChooseMultiplePublic(BaseModel):
    """
    ScreenerQuestionChooseMultiplePublic
    """ # noqa: E501
    type: StrictStr
    question: StrictStr
    image_file_id: Optional[Annotated[str, Field(strict=True, max_length=36)]] = Field(default=None, description="File ID for question image", alias="imageFileId")
    options: Dict[str, ScreenerQuestionChooseMultipleOptionsValue]
    randomize_order: Optional[StrictBool] = Field(default=None, alias="randomizeOrder")
    show_select_all_of_above: StrictBool = Field(alias="showSelectAllOfAbove")
    show_select_none_of_above: StrictBool = Field(alias="showSelectNoneOfAbove")
    image_url: Optional[StrictStr] = Field(default=None, description="Signed URL for question image (enriched for participant view)", alias="imageUrl")
    __properties: ClassVar[List[str]] = ["type", "question", "imageFileId", "options", "randomizeOrder", "showSelectAllOfAbove", "showSelectNoneOfAbove", "imageUrl"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['chooseMultiple']):
            raise ValueError("must be one of enum values ('chooseMultiple')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ScreenerQuestionChooseMultiplePublic from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in options (dict)
        _field_dict = {}
        if self.options:
            for _key_options in self.options:
                if self.options[_key_options]:
                    _field_dict[_key_options] = self.options[_key_options].to_dict()
            _dict['options'] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ScreenerQuestionChooseMultiplePublic from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "question": obj.get("question"),
            "imageFileId": obj.get("imageFileId"),
            "options": dict(
                (_k, ScreenerQuestionChooseMultipleOptionsValue.from_dict(_v))
                for _k, _v in obj["options"].items()
            )
            if obj.get("options") is not None
            else None,
            "randomizeOrder": obj.get("randomizeOrder"),
            "showSelectAllOfAbove": obj.get("showSelectAllOfAbove"),
            "showSelectNoneOfAbove": obj.get("showSelectNoneOfAbove"),
            "imageUrl": obj.get("imageUrl")
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.thread_metadata import ThreadMetadata

class TestThreadMetadata(unittest.TestCase):
    """ThreadMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ThreadMetadata:
        """Test ThreadMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ThreadMetadata`
        """
        model = ThreadMetadata()
        if include_optional:
            return ThreadMetadata(
                status = 'draft',
                project_brief_drafts = [
                    keplar_api.models.project_brief.ProjectBrief(
                        title = '', 
                        objective = '', 
                        learning_goals = '', 
                        key_questions = '', 
                        conversation_flow = [
                            ''
                            ], 
                        rules = [
                            ''
                            ], 
                        assets = [
                            ''
                            ], )
                    ],
                project_brief_document_versions = [
                    keplar_api.models.brief_document_version.BriefDocumentVersion(
                        doc = keplar_api.models.brief_document.BriefDocument(
                            type = 'doc', 
                            content = [
                                keplar_api.models.content_node.ContentNode()
                                ], ), 
                        version = 1.337, 
                        created_at = '', 
                        updated_at = '', )
                    ]
            )
        else:
            return ThreadMetadata(
        )
        """

    def testThreadMetadata(self):
        """Test ThreadMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.conversation_message_topic import ConversationMessageTopic

class TestConversationMessageTopic(unittest.TestCase):
    """ConversationMessageTopic unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ConversationMessageTopic:
        """Test ConversationMessageTopic
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ConversationMessageTopic`
        """
        model = ConversationMessageTopic()
        if include_optional:
            return ConversationMessageTopic(
                call_id = '',
                index = 1.337,
                description = '',
                call = keplar_api.models.call.Call(
                    id = '', 
                    vendor = '', 
                    vendor_call_id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    duration_ms = 1.337, 
                    kind = 'VOICE_CALL', 
                    status = 'REQUESTED', 
                    phone_number = '', 
                    metadata = keplar_api.models.call_metadata.CallMetadata(
                        recording_url = '', 
                        transcript = '', 
                        transcript_quality = 'HIGH', 
                        transcript_markdown = '', 
                        transcript_insight = '', 
                        analysis = keplar_api.models.call_analysis.CallAnalysis(
                            summary = '', 
                            success_evaluation = '', ), 
                        gcs_url = '', 
                        gcs_path = '', 
                        gcs_uploaded_at = '', 
                        gcs_last_synced_at = '', 
                        video_recording_url = '', 
                        video_gcs_url = '', 
                        video_gcs_path = '', 
                        video_uploaded_at = '', 
                        video_mime_type = '', 
                        video_duration_seconds = 1.337, 
                        video_size_bytes = 1.337, 
                        video_recording_status = 'recording', 
                        video_recording_error = '', ), 
                    invite_response_id = '', 
                    participant_id = '', 
                    invite_id = '', 
                    analysis = null, 
                    invite_response = keplar_api.models.invite_response.InviteResponse(
                        id = '', 
                        kind = 'VOICE_CALL', 
                        status = 'PENDING', 
                        data = keplar_api.models.invite_response_data.InviteResponseData(
                            email = '', 
                            screener_questions_responses = [
                                keplar_api.models.screener_question_response.ScreenerQuestionResponse(
                                    question = '', 
                                    response = null, )
                                ], 
                            consented = True, 
                            redirected = True, ), 
                        evaluation = 'SYSTEM_PASS', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        invite_id = '', 
                        vendor_participant_id = '', 
                        participant_id = '', 
                        invite = keplar_api.models.invite.Invite(
                            id = '', 
                            name = '', 
                            description = '', 
                            config = keplar_api.models.invite_config.InviteConfig(), 
                            code = '', 
                            status = 'PREVIEW', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            created_by_id = '', 
                            project_id = '', 
                            created_by = keplar_api.models.user.User(
                                id = '', 
                                seq = 1.337, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                provider = 'google', 
                                user_id = '', 
                                email = '', 
                                name = '', 
                                account_status = 'ACTIVE', 
                                location = '', 
                                profile_image_url = '', 
                                password_hash = '', 
                                email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                token = '', 
                                token_kind = 'email_verification', 
                                token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                org_id = '', 
                                default_workspace_id = '', 
                                org = keplar_api.models.org.Org(
                                    id = '', 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    name = '', 
                                    domain = '', 
                                    default_workspace_id = '', 
                                    users = [
                                        keplar_api.models.user.User(
                                            id = '', 
                                            seq = 1.337, 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            provider = 'google', 
                                            user_id = '', 
                                            email = '', 
                                            name = '', 
                                            account_status = 'ACTIVE', 
                                            location = '', 
                                            profile_image_url = '', 
                                            password_hash = '', 
                                            email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            token = '', 
                                            token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            org_id = '', 
                                            default_workspace_id = '', 
                                            default_workspace = keplar_api.models.workspace.Workspace(
                                                id = '', 
                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                name = '', 
                                                projects = [
                                                    keplar_api.models.project.Project(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        description = '', 
                                                        status = 'ACTIVE', 
                                                        created_by_id = '', 
                                                        workspace_id = '', 
                                                        moderator_id = '', 
                                                        config = keplar_api.models.project_config.ProjectConfig(
                                                            project_kind = 'custom', 
                                                            prompt_variables = {
                                                                'key' : null
                                                                }, 
                                                            learning_plan = '', 
                                                            brief = keplar_api.models.project_brief.ProjectBrief(
                                                                title = '', 
                                                                objective = '', 
                                                                learning_goals = '', 
                                                                key_questions = '', 
                                                                conversation_flow = [
                                                                    ''
                                                                    ], 
                                                                rules = [
                                                                    ''
                                                                    ], 
                                                                assets = [
                                                                    ''
                                                                    ], ), 
                                                            current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                                                doc = keplar_api.models.brief_document.BriefDocument(
                                                                    type = 'doc', 
                                                                    content = [
                                                                        keplar_api.models.content_node.ContentNode()
                                                                        ], ), 
                                                                version = 1.337, 
                                                                created_at = '', 
                                                                updated_at = '', ), 
                                                            brief_document = '', 
                                                            screener_questions = [
                                                                keplar_api.models.screener_question.ScreenerQuestion()
                                                                ], 
                                                            audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                                                sample_size = 1.337, 
                                                                invite_title = '', 
                                                                invite_description = '', 
                                                                participants = [
                                                                    keplar_api.models.participant_create.ParticipantCreate(
                                                                        id = '', 
                                                                        name = '', 
                                                                        email = '', 
                                                                        phone_number = '01234', )
                                                                    ], 
                                                                panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                                                    respondent_attributes = [
                                                                        keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                                                            qualifications = [
                                                                                keplar_api.models.panel_qualification.PanelQualification(
                                                                                    allowed_option_ids = [
                                                                                        null
                                                                                        ], 
                                                                                    question_id = 1.337, )
                                                                                ], 
                                                                            quota = 1.337, 
                                                                            quota_name = '', )
                                                                        ], 
                                                                    country_code = '', 
                                                                    language_code = '', 
                                                                    length_of_interview = 1.337, 
                                                                    incidence_rate = 1.337, 
                                                                    compensation = 1.337, ), 
                                                                use_public_link = True, ), ), 
                                                        conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                            first_message = '', 
                                                            end_call_message = '', 
                                                            max_duration_seconds = 1.337, 
                                                            voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                provider = 'vapi', 
                                                                voice_id = 'Elliot', ), 
                                                            language = 'en', ), 
                                                        workspace = keplar_api.models.workspace.Workspace(
                                                            id = '', 
                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                            name = '', 
                                                            moderators = [
                                                                keplar_api.models.moderator.Moderator(
                                                                    id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    visibility = 'public', 
                                                                    config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                        system_prompt = '', 
                                                                        model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                            provider = 'openai', 
                                                                            model = 'gpt-4.1', ), 
                                                                        first_message = '', 
                                                                        end_call_message = '', 
                                                                        max_duration_seconds = 1.337, 
                                                                        voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                            provider = 'vapi', 
                                                                            voice_id = 'Elliot', ), 
                                                                        tools = [
                                                                            keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                                                                type = 'function', 
                                                                                function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                                                                    name = '', 
                                                                                    description = '', 
                                                                                    parameters = {
                                                                                        'key' : null
                                                                                        }, ), )
                                                                            ], ), 
                                                                    vendor = 'vapi', 
                                                                    vendor_id = '', 
                                                                    vendor_data = null, 
                                                                    workspace_id = '', 
                                                                    created_by_id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    parent_moderator_id = '', 
                                                                    parent_moderator = keplar_api.models.moderator.Moderator(
                                                                        id = '', 
                                                                        name = '', 
                                                                        description = '', 
                                                                        visibility = 'public', 
                                                                        config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                            system_prompt = '', 
                                                                            model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                                provider = 'openai', 
                                                                                model = 'gpt-4.1', ), 
                                                                            first_message = '', 
                                                                            end_call_message = '', 
                                                                            max_duration_seconds = 1.337, 
                                                                            voice = , ), 
                                                                        vendor = 'vapi', 
                                                                        vendor_id = '', 
                                                                        vendor_data = null, 
                                                                        workspace_id = '', 
                                                                        created_by_id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        parent_moderator_id = '', 
                                                                        child_moderators = [
                                                                            
                                                                            ], ), 
                                                                    child_moderators = [
                                                                        
                                                                        ], )
                                                                ], 
                                                            files = [
                                                                keplar_api.models.file.File(
                                                                    id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    filename = '', 
                                                                    display_name = '', 
                                                                    mime_type = 'image/jpeg', 
                                                                    size = '', 
                                                                    bucket_name = '', 
                                                                    gcs_path = '', 
                                                                    gcs_generation = '', 
                                                                    uploaded_by_id = '', 
                                                                    workspace_id = '', 
                                                                    description = '', 
                                                                    is_public = True, 
                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    public_url = '', 
                                                                    public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    uploaded_by = , 
                                                                    project_files = [
                                                                        keplar_api.models.project_file.ProjectFile(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            project_id = '', 
                                                                            file_id = '', 
                                                                            description = '', 
                                                                            category = 'transcript', 
                                                                            project = keplar_api.models.project.Project(
                                                                                id = '', 
                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                name = '', 
                                                                                description = '', 
                                                                                status = 'ACTIVE', 
                                                                                created_by_id = '', 
                                                                                workspace_id = '', 
                                                                                moderator_id = '', 
                                                                                config = keplar_api.models.project_config.ProjectConfig(
                                                                                    prompt_variables = {
                                                                                        'key' : null
                                                                                        }, 
                                                                                    learning_plan = '', 
                                                                                    brief_document = '', ), 
                                                                                conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                                    first_message = '', 
                                                                                    end_call_message = '', 
                                                                                    max_duration_seconds = 1.337, 
                                                                                    voice = , ), 
                                                                                moderator = , 
                                                                                invites = [
                                                                                    keplar_api.models.invite.Invite(
                                                                                        id = '', 
                                                                                        name = '', 
                                                                                        description = '', 
                                                                                        config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                        code = '', 
                                                                                        status = 'PREVIEW', 
                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        created_by_id = '', 
                                                                                        project_id = '', 
                                                                                        calls = [
                                                                                            keplar_api.models.call.Call(
                                                                                                id = '', 
                                                                                                vendor = '', 
                                                                                                vendor_call_id = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                duration_ms = 1.337, 
                                                                                                phone_number = '', 
                                                                                                invite_response_id = '', 
                                                                                                participant_id = '', 
                                                                                                invite_id = '', 
                                                                                                events = [
                                                                                                    keplar_api.models.call_event.CallEvent(
                                                                                                        call_id = '', 
                                                                                                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        kind = '', 
                                                                                                        data = keplar_api.models.call_event_data.CallEventData(), )
                                                                                                    ], 
                                                                                                participant = keplar_api.models.participant.Participant(
                                                                                                    id = '', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    email = '', 
                                                                                                    phone_number = '', 
                                                                                                    name = '', 
                                                                                                    workspace_id = '', 
                                                                                                    participant_invites = [
                                                                                                        keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                            code = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            participant_id = '', 
                                                                                                            invite_id = '', )
                                                                                                        ], 
                                                                                                    invite_responses = [
                                                                                                        keplar_api.models.invite_response.InviteResponse(
                                                                                                            id = '', 
                                                                                                            kind = 'VOICE_CALL', 
                                                                                                            status = 'PENDING', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            invite_id = '', 
                                                                                                            vendor_participant_id = '', 
                                                                                                            participant_id = '', 
                                                                                                            invite_response_attributes = [
                                                                                                                keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                    invite_response_id = '', 
                                                                                                                    attribute_id = '', 
                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                    attribute = keplar_api.models.attribute.Attribute(
                                                                                                                        id = '', 
                                                                                                                        attribute_kind_id = '', 
                                                                                                                        value = '', 
                                                                                                                        description = '', 
                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                        attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                            id = '', 
                                                                                                                            key = '', 
                                                                                                                            label = '', 
                                                                                                                            value_kind = 'single', 
                                                                                                                            description = '', 
                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                            attribute_kind_group_id = '', 
                                                                                                                            attributes = [
                                                                                                                                keplar_api.models.attribute.Attribute(
                                                                                                                                    id = '', 
                                                                                                                                    attribute_kind_id = '', 
                                                                                                                                    value = '', 
                                                                                                                                    description = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    participant_attributes = [
                                                                                                                                        keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                            participant_id = '', 
                                                                                                                                            attribute_id = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                        ], )
                                                                                                                                ], 
                                                                                                                            attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                                                id = '', 
                                                                                                                                name = '', 
                                                                                                                                description = '', 
                                                                                                                                scope = 'org', 
                                                                                                                                purpose = 'screener_response', 
                                                                                                                                workspace_id = '', 
                                                                                                                                project_id = '', 
                                                                                                                                created_by_id = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                attribute_kinds = [
                                                                                                                                    keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                        id = '', 
                                                                                                                                        key = '', 
                                                                                                                                        label = '', 
                                                                                                                                        value_kind = 'single', 
                                                                                                                                        description = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        attribute_kind_group_id = '', )
                                                                                                                                    ], 
                                                                                                                                artifacts = [
                                                                                                                                    keplar_api.models.artifact.Artifact(
                                                                                                                                        id = '', 
                                                                                                                                        title = '', 
                                                                                                                                        kind = 'thematic_analysis', 
                                                                                                                                        project_id = '', 
                                                                                                                                        attribute_kind_group_id = '', 
                                                                                                                                        version_group_id = '', 
                                                                                                                                        metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                            status = 'draft', 
                                                                                                                                            status_message = '', 
                                                                                                                                            progress = 1.337, 
                                                                                                                                            description = '', ), 
                                                                                                                                        created_by_id = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                            id = '', 
                                                                                                                                            project_id = '', 
                                                                                                                                            kind = 'thematic_analysis', 
                                                                                                                                            latest_artifact_id = '', 
                                                                                                                                            latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                                                                id = '', 
                                                                                                                                                title = '', 
                                                                                                                                                kind = , 
                                                                                                                                                project_id = '', 
                                                                                                                                                attribute_kind_group_id = '', 
                                                                                                                                                version_group_id = '', 
                                                                                                                                                metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                    status = 'draft', 
                                                                                                                                                    status_message = '', 
                                                                                                                                                    progress = 1.337, 
                                                                                                                                                    description = '', ), 
                                                                                                                                                created_by_id = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                latest_for_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                    id = '', 
                                                                                                                                                    project_id = '', 
                                                                                                                                                    kind = , 
                                                                                                                                                    latest_artifact_id = '', 
                                                                                                                                                    notebook_artifact_version_groups = [
                                                                                                                                                        keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                            id = '', 
                                                                                                                                                            notebook_id = '', 
                                                                                                                                                            artifact_version_group_id = '', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            notebook = keplar_api.models.notebook.Notebook(
                                                                                                                                                                id = '', 
                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                created_by_id = '', 
                                                                                                                                                                name = '', 
                                                                                                                                                                description = '', 
                                                                                                                                                                config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                                                                                                    sources = [
                                                                                                                                                                        ''
                                                                                                                                                                        ], 
                                                                                                                                                                    mode = 'report', 
                                                                                                                                                                    settings = keplar_api.models.settings.settings(), ), 
                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                threads = [
                                                                                                                                                                    keplar_api.models.thread.Thread(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        name = '', 
                                                                                                                                                                        description = '', 
                                                                                                                                                                        created_by_id = '', 
                                                                                                                                                                        workspace_id = '', 
                                                                                                                                                                        project_id = '', 
                                                                                                                                                                        notebook_id = '', 
                                                                                                                                                                        thread_files = [
                                                                                                                                                                            keplar_api.models.thread_file.ThreadFile(
                                                                                                                                                                                id = '', 
                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                thread_id = '', 
                                                                                                                                                                                file_id = '', 
                                                                                                                                                                                thread = keplar_api.models.thread.Thread(
                                                                                                                                                                                    id = '', 
                                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    name = '', 
                                                                                                                                                                                    description = '', 
                                                                                                                                                                                    created_by_id = '', 
                                                                                                                                                                                    workspace_id = '', 
                                                                                                                                                                                    project_id = '', 
                                                                                                                                                                                    notebook_id = '', ), 
                                                                                                                                                                                file = keplar_api.models.file.File(
                                                                                                                                                                                    id = '', 
                                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    filename = '', 
                                                                                                                                                                                    display_name = '', 
                                                                                                                                                                                    mime_type = 'image/jpeg', 
                                                                                                                                                                                    size = '', 
                                                                                                                                                                                    bucket_name = '', 
                                                                                                                                                                                    gcs_path = '', 
                                                                                                                                                                                    gcs_generation = '', 
                                                                                                                                                                                    uploaded_by_id = '', 
                                                                                                                                                                                    workspace_id = '', 
                                                                                                                                                                                    description = '', 
                                                                                                                                                                                    is_public = True, 
                                                                                                                                                                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                    public_url = '', 
                                                                                                                                                                                    public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                                                                                                                                                            ], )
                                                                                                                                                                    ], ), 
                                                                                                                                                            artifact_version_group = , )
                                                                                                                                                        ], ), ), 
                                                                                                                                            notebook_artifact_version_groups = [
                                                                                                                                                keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                    id = '', 
                                                                                                                                                    notebook_id = '', 
                                                                                                                                                    artifact_version_group_id = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                ], ), 
                                                                                                                                        latest_for_group = , )
                                                                                                                                    ], ), ), 
                                                                                                                        participant_attributes = [
                                                                                                                            keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                participant_id = '', 
                                                                                                                                attribute_id = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                            ], ), )
                                                                                                                ], )
                                                                                                        ], 
                                                                                                    participant_attributes = , ), 
                                                                                                conversation_messages = [
                                                                                                    keplar_api.models.conversation_message.ConversationMessage(
                                                                                                        call_id = '', 
                                                                                                        index = 1.337, 
                                                                                                        role = '', 
                                                                                                        source = '', 
                                                                                                        time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        message = '', 
                                                                                                        duration = 1.337, 
                                                                                                        seconds_from_start = 1.337, 
                                                                                                        conversation_message_topic_index = 1.337, 
                                                                                                        conversation_message_topic = keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                            call_id = '', 
                                                                                                            index = 1.337, 
                                                                                                            description = '', ), )
                                                                                                    ], 
                                                                                                conversation_message_topics = [
                                                                                                    keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                        call_id = '', 
                                                                                                        index = 1.337, 
                                                                                                        description = '', )
                                                                                                    ], )
                                                                                            ], 
                                                                                        participant_invites = [
                                                                                            keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                code = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                participant_id = '', 
                                                                                                invite_id = '', )
                                                                                            ], 
                                                                                        invite_responses = [
                                                                                            
                                                                                            ], )
                                                                                    ], 
                                                                                chat_sessions = [
                                                                                    keplar_api.models.chat_session.ChatSession(
                                                                                        id = '', 
                                                                                        name = '', 
                                                                                        description = '', 
                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        created_by_id = '', 
                                                                                        project_id = '', 
                                                                                        chat_messages = [
                                                                                            keplar_api.models.chat_message.ChatMessage(
                                                                                                id = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                content = '', 
                                                                                                role = 'user', 
                                                                                                chat_session_id = '', 
                                                                                                chat_session = keplar_api.models.chat_session.ChatSession(
                                                                                                    id = '', 
                                                                                                    name = '', 
                                                                                                    description = '', 
                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                    created_by_id = '', 
                                                                                                    project_id = '', ), )
                                                                                            ], )
                                                                                    ], 
                                                                                threads = [
                                                                                    
                                                                                    ], 
                                                                                attribute_kind_group = [
                                                                                    keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                        id = '', 
                                                                                        name = '', 
                                                                                        description = '', 
                                                                                        scope = 'org', 
                                                                                        purpose = 'screener_response', 
                                                                                        workspace_id = '', 
                                                                                        project_id = '', 
                                                                                        created_by_id = '', 
                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                    ], 
                                                                                artifacts = [
                                                                                    
                                                                                    ], 
                                                                                artifact_version_group = [
                                                                                    
                                                                                    ], ), 
                                                                            file = , )
                                                                        ], 
                                                                    thread_files = [
                                                                        keplar_api.models.thread_file.ThreadFile(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            thread_id = '', 
                                                                            file_id = '', )
                                                                        ], )
                                                                ], 
                                                            threads = , 
                                                            attribute_kind_groups = [
                                                                
                                                                ], 
                                                            workspace_members = [
                                                                keplar_api.models.workspace_member.WorkspaceMember(
                                                                    id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    role = 'owner', 
                                                                    user_id = '', 
                                                                    workspace_id = '', 
                                                                    user = , )
                                                                ], 
                                                            notebooks = [
                                                                keplar_api.models.notebook.Notebook(
                                                                    id = '', 
                                                                    workspace_id = '', 
                                                                    created_by_id = '', 
                                                                    name = '', 
                                                                    description = '', 
                                                                    config = keplar_api.models.notebook_config.NotebookConfig(
                                                                        sources = [
                                                                            ''
                                                                            ], 
                                                                        mode = 'report', 
                                                                        settings = keplar_api.models.settings.settings(), ), 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                ], 
                                                            default_for_users = [
                                                                
                                                                ], 
                                                            default_for_orgs = [
                                                                keplar_api.models.org.Org(
                                                                    id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    name = '', 
                                                                    domain = '', 
                                                                    default_workspace_id = '', )
                                                                ], ), 
                                                        moderator = , 
                                                        invites = [
                                                            
                                                            ], 
                                                        chat_sessions = [
                                                            
                                                            ], 
                                                        project_files = [
                                                            keplar_api.models.project_file.ProjectFile(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                project_id = '', 
                                                                file_id = '', 
                                                                description = '', )
                                                            ], 
                                                        threads = , 
                                                        attribute_kind_group = [
                                                            
                                                            ], 
                                                        artifacts = , 
                                                        artifact_version_group = [
                                                            
                                                            ], )
                                                    ], 
                                                participants = [
                                                    keplar_api.models.participant.Participant(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        email = '', 
                                                        phone_number = '', 
                                                        name = '', 
                                                        workspace_id = '', )
                                                    ], 
                                                moderators = [
                                                    
                                                    ], 
                                                files = [
                                                    
                                                    ], 
                                                threads = , 
                                                attribute_kind_groups = [
                                                    
                                                    ], 
                                                workspace_members = [
                                                    keplar_api.models.workspace_member.WorkspaceMember(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        role = 'owner', 
                                                        user_id = '', 
                                                        workspace_id = '', )
                                                    ], 
                                                notebooks = [
                                                    
                                                    ], 
                                                default_for_users = [
                                                    
                                                    ], 
                                                default_for_orgs = [
                                                    
                                                    ], ), 
                                            workspace_members = , 
                                            projects = [
                                                
                                                ], 
                                            invites = , 
                                            chat_sessions = , 
                                            moderators = , 
                                            uploaded_files = [
                                                
                                                ], 
                                            threads = , 
                                            attribute_kind_group = , 
                                            artifact = [
                                                
                                                ], 
                                            notebooks = , )
                                        ], 
                                    default_workspace = , ), 
                                default_workspace = , 
                                workspace_members = , 
                                projects = , 
                                invites = , 
                                chat_sessions = , 
                                moderators = , 
                                uploaded_files = [
                                    
                                    ], 
                                threads = , 
                                attribute_kind_group = , 
                                artifact = [
                                    
                                    ], 
                                notebooks = , ), 
                            project = , 
                            calls = [
                                
                                ], 
                            participant_invites = , 
                            invite_responses = , ), 
                        participant = , 
                        calls = , 
                        invite_response_attributes = [
                            keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                invite_response_id = '', 
                                attribute_id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], ), 
                    events = [
                        keplar_api.models.call_event.CallEvent(
                            call_id = '', 
                            timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            kind = '', 
                            data = keplar_api.models.call_event_data.CallEventData(), )
                        ], 
                    participant = , 
                    invite = , 
                    conversation_messages = [
                        keplar_api.models.conversation_message.ConversationMessage(
                            call_id = '', 
                            index = 1.337, 
                            role = '', 
                            source = '', 
                            time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            message = '', 
                            duration = 1.337, 
                            seconds_from_start = 1.337, 
                            conversation_message_topic_index = 1.337, )
                        ], 
                    conversation_message_topics = [
                        
                        ], ),
                conversation_messages = [
                    keplar_api.models.conversation_message.ConversationMessage(
                        call_id = '', 
                        index = 1.337, 
                        role = '', 
                        source = '', 
                        time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        message = '', 
                        duration = 1.337, 
                        seconds_from_start = 1.337, 
                        conversation_message_topic_index = 1.337, 
                        call = keplar_api.models.call.Call(
                            id = '', 
                            vendor = '', 
                            vendor_call_id = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            duration_ms = 1.337, 
                            kind = 'VOICE_CALL', 
                            status = 'REQUESTED', 
                            phone_number = '', 
                            metadata = keplar_api.models.call_metadata.CallMetadata(
                                recording_url = '', 
                                transcript = '', 
                                transcript_quality = 'HIGH', 
                                transcript_markdown = '', 
                                transcript_insight = '', 
                                analysis = keplar_api.models.call_analysis.CallAnalysis(
                                    summary = '', 
                                    success_evaluation = '', ), 
                                gcs_url = '', 
                                gcs_path = '', 
                                gcs_uploaded_at = '', 
                                gcs_last_synced_at = '', 
                                video_recording_url = '', 
                                video_gcs_url = '', 
                                video_gcs_path = '', 
                                video_uploaded_at = '', 
                                video_mime_type = '', 
                                video_duration_seconds = 1.337, 
                                video_size_bytes = 1.337, 
                                video_recording_status = 'recording', 
                                video_recording_error = '', ), 
                            invite_response_id = '', 
                            participant_id = '', 
                            invite_id = '', 
                            analysis = null, 
                            invite_response = keplar_api.models.invite_response.InviteResponse(
                                id = '', 
                                kind = 'VOICE_CALL', 
                                status = 'PENDING', 
                                data = keplar_api.models.invite_response_data.InviteResponseData(
                                    email = '', 
                                    screener_questions_responses = [
                                        keplar_api.models.screener_question_response.ScreenerQuestionResponse(
                                            question = '', 
                                            response = null, )
                                        ], 
                                    consented = True, 
                                    redirected = True, ), 
                                evaluation = 'SYSTEM_PASS', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                invite_id = '', 
                                vendor_participant_id = '', 
                                participant_id = '', 
                                invite = keplar_api.models.invite.Invite(
                                    id = '', 
                                    name = '', 
                                    description = '', 
                                    config = keplar_api.models.invite_config.InviteConfig(), 
                                    code = '', 
                                    status = 'PREVIEW', 
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    created_by_id = '', 
                                    project_id = '', 
                                    created_by = keplar_api.models.user.User(
                                        id = '', 
                                        seq = 1.337, 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        provider = 'google', 
                                        user_id = '', 
                                        email = '', 
                                        name = '', 
                                        account_status = 'ACTIVE', 
                                        location = '', 
                                        profile_image_url = '', 
                                        password_hash = '', 
                                        email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        token = '', 
                                        token_kind = 'email_verification', 
                                        token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                        org_id = '', 
                                        default_workspace_id = '', 
                                        org = keplar_api.models.org.Org(
                                            id = '', 
                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                            name = '', 
                                            domain = '', 
                                            default_workspace_id = '', 
                                            users = [
                                                keplar_api.models.user.User(
                                                    id = '', 
                                                    seq = 1.337, 
                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    provider = 'google', 
                                                    user_id = '', 
                                                    email = '', 
                                                    name = '', 
                                                    account_status = 'ACTIVE', 
                                                    location = '', 
                                                    profile_image_url = '', 
                                                    password_hash = '', 
                                                    email_verified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    token = '', 
                                                    token_expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                    org_id = '', 
                                                    default_workspace_id = '', 
                                                    default_workspace = keplar_api.models.workspace.Workspace(
                                                        id = '', 
                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                        name = '', 
                                                        projects = [
                                                            keplar_api.models.project.Project(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                name = '', 
                                                                description = '', 
                                                                status = 'ACTIVE', 
                                                                created_by_id = '', 
                                                                workspace_id = '', 
                                                                moderator_id = '', 
                                                                config = keplar_api.models.project_config.ProjectConfig(
                                                                    project_kind = 'custom', 
                                                                    prompt_variables = {
                                                                        'key' : null
                                                                        }, 
                                                                    learning_plan = '', 
                                                                    brief = keplar_api.models.project_brief.ProjectBrief(
                                                                        title = '', 
                                                                        objective = '', 
                                                                        learning_goals = '', 
                                                                        key_questions = '', 
                                                                        conversation_flow = [
                                                                            ''
                                                                            ], 
                                                                        rules = [
                                                                            ''
                                                                            ], 
                                                                        assets = [
                                                                            ''
                                                                            ], ), 
                                                                    current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                                                                        doc = keplar_api.models.brief_document.BriefDocument(
                                                                            type = 'doc', 
                                                                            content = [
                                                                                keplar_api.models.content_node.ContentNode()
                                                                                ], ), 
                                                                        version = 1.337, 
                                                                        created_at = '', 
                                                                        updated_at = '', ), 
                                                                    brief_document = '', 
                                                                    screener_questions = [
                                                                        keplar_api.models.screener_question.ScreenerQuestion()
                                                                        ], 
                                                                    audience_settings = keplar_api.models.project_audience.ProjectAudience(
                                                                        sample_size = 1.337, 
                                                                        invite_title = '', 
                                                                        invite_description = '', 
                                                                        participants = [
                                                                            keplar_api.models.participant_create.ParticipantCreate(
                                                                                id = '', 
                                                                                name = '', 
                                                                                email = '', 
                                                                                phone_number = '01234', )
                                                                            ], 
                                                                        panel_settings = keplar_api.models.panel_settings.PanelSettings(
                                                                            respondent_attributes = [
                                                                                keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                                                                    qualifications = [
                                                                                        keplar_api.models.panel_qualification.PanelQualification(
                                                                                            allowed_option_ids = [
                                                                                                null
                                                                                                ], 
                                                                                            question_id = 1.337, )
                                                                                        ], 
                                                                                    quota = 1.337, 
                                                                                    quota_name = '', )
                                                                                ], 
                                                                            country_code = '', 
                                                                            language_code = '', 
                                                                            length_of_interview = 1.337, 
                                                                            incidence_rate = 1.337, 
                                                                            compensation = 1.337, ), 
                                                                        use_public_link = True, ), ), 
                                                                conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                    first_message = '', 
                                                                    end_call_message = '', 
                                                                    max_duration_seconds = 1.337, 
                                                                    voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                        provider = 'vapi', 
                                                                        voice_id = 'Elliot', ), 
                                                                    language = 'en', ), 
                                                                workspace = keplar_api.models.workspace.Workspace(
                                                                    id = '', 
                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                    name = '', 
                                                                    moderators = [
                                                                        keplar_api.models.moderator.Moderator(
                                                                            id = '', 
                                                                            name = '', 
                                                                            description = '', 
                                                                            visibility = 'public', 
                                                                            config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                                system_prompt = '', 
                                                                                model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                                    provider = 'openai', 
                                                                                    model = 'gpt-4.1', ), 
                                                                                first_message = '', 
                                                                                end_call_message = '', 
                                                                                max_duration_seconds = 1.337, 
                                                                                voice = keplar_api.models.vapi_voice_vapi_provider.VapiVoiceVapiProvider(
                                                                                    provider = 'vapi', 
                                                                                    voice_id = 'Elliot', ), 
                                                                                tools = [
                                                                                    keplar_api.models.chat_completion_tool.ChatCompletionTool(
                                                                                        type = 'function', 
                                                                                        function = keplar_api.models.chat_completion_tool_function.ChatCompletionTool_function(
                                                                                            name = '', 
                                                                                            description = '', 
                                                                                            parameters = {
                                                                                                'key' : null
                                                                                                }, ), )
                                                                                    ], ), 
                                                                            vendor = 'vapi', 
                                                                            vendor_id = '', 
                                                                            vendor_data = null, 
                                                                            workspace_id = '', 
                                                                            created_by_id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            parent_moderator_id = '', 
                                                                            parent_moderator = keplar_api.models.moderator.Moderator(
                                                                                id = '', 
                                                                                name = '', 
                                                                                description = '', 
                                                                                visibility = 'public', 
                                                                                config = keplar_api.models.vapi_assistant_config.VapiAssistantConfig(
                                                                                    system_prompt = '', 
                                                                                    model = keplar_api.models.open_ai_model_config.OpenAiModelConfig(
                                                                                        provider = 'openai', 
                                                                                        model = 'gpt-4.1', ), 
                                                                                    first_message = '', 
                                                                                    end_call_message = '', 
                                                                                    max_duration_seconds = 1.337, 
                                                                                    voice = , ), 
                                                                                vendor = 'vapi', 
                                                                                vendor_id = '', 
                                                                                vendor_data = null, 
                                                                                workspace_id = '', 
                                                                                created_by_id = '', 
                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                parent_moderator_id = '', 
                                                                                child_moderators = [
                                                                                    
                                                                                    ], ), 
                                                                            child_moderators = [
                                                                                
                                                                                ], )
                                                                        ], 
                                                                    files = [
                                                                        keplar_api.models.file.File(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            filename = '', 
                                                                            display_name = '', 
                                                                            mime_type = 'image/jpeg', 
                                                                            size = '', 
                                                                            bucket_name = '', 
                                                                            gcs_path = '', 
                                                                            gcs_generation = '', 
                                                                            uploaded_by_id = '', 
                                                                            workspace_id = '', 
                                                                            description = '', 
                                                                            is_public = True, 
                                                                            expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            public_url = '', 
                                                                            public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            uploaded_by = , 
                                                                            project_files = [
                                                                                keplar_api.models.project_file.ProjectFile(
                                                                                    id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    project_id = '', 
                                                                                    file_id = '', 
                                                                                    description = '', 
                                                                                    category = 'transcript', 
                                                                                    project = keplar_api.models.project.Project(
                                                                                        id = '', 
                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                        name = '', 
                                                                                        description = '', 
                                                                                        status = 'ACTIVE', 
                                                                                        created_by_id = '', 
                                                                                        workspace_id = '', 
                                                                                        moderator_id = '', 
                                                                                        config = keplar_api.models.project_config.ProjectConfig(
                                                                                            prompt_variables = {
                                                                                                'key' : null
                                                                                                }, 
                                                                                            learning_plan = '', 
                                                                                            brief_document = '', ), 
                                                                                        conversation_config = keplar_api.models.project_conversation_config.ProjectConversationConfig(
                                                                                            first_message = '', 
                                                                                            end_call_message = '', 
                                                                                            max_duration_seconds = 1.337, 
                                                                                            voice = , ), 
                                                                                        moderator = , 
                                                                                        invites = [
                                                                                            keplar_api.models.invite.Invite(
                                                                                                id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                config = keplar_api.models.invite_config.InviteConfig(), 
                                                                                                code = '', 
                                                                                                status = 'PREVIEW', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                live_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                created_by_id = '', 
                                                                                                project_id = '', 
                                                                                                calls = [
                                                                                                    keplar_api.models.call.Call(
                                                                                                        id = '', 
                                                                                                        vendor = '', 
                                                                                                        vendor_call_id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        ended_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        duration_ms = 1.337, 
                                                                                                        phone_number = '', 
                                                                                                        invite_response_id = '', 
                                                                                                        participant_id = '', 
                                                                                                        invite_id = '', 
                                                                                                        events = [
                                                                                                            keplar_api.models.call_event.CallEvent(
                                                                                                                call_id = '', 
                                                                                                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                kind = '', 
                                                                                                                data = keplar_api.models.call_event_data.CallEventData(), )
                                                                                                            ], 
                                                                                                        participant = keplar_api.models.participant.Participant(
                                                                                                            id = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            email = '', 
                                                                                                            phone_number = '', 
                                                                                                            name = '', 
                                                                                                            workspace_id = '', 
                                                                                                            participant_invites = [
                                                                                                                keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                                    code = '', 
                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                    participant_id = '', 
                                                                                                                    invite_id = '', )
                                                                                                                ], 
                                                                                                            invite_responses = [
                                                                                                                keplar_api.models.invite_response.InviteResponse(
                                                                                                                    id = '', 
                                                                                                                    kind = 'VOICE_CALL', 
                                                                                                                    status = 'PENDING', 
                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                    invite_id = '', 
                                                                                                                    vendor_participant_id = '', 
                                                                                                                    participant_id = '', 
                                                                                                                    invite_response_attributes = [
                                                                                                                        keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                                                                                                            invite_response_id = '', 
                                                                                                                            attribute_id = '', 
                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                            attribute = keplar_api.models.attribute.Attribute(
                                                                                                                                id = '', 
                                                                                                                                attribute_kind_id = '', 
                                                                                                                                value = '', 
                                                                                                                                description = '', 
                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                attribute_kind = keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                    id = '', 
                                                                                                                                    key = '', 
                                                                                                                                    label = '', 
                                                                                                                                    value_kind = 'single', 
                                                                                                                                    description = '', 
                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                    attribute_kind_group_id = '', 
                                                                                                                                    attributes = [
                                                                                                                                        keplar_api.models.attribute.Attribute(
                                                                                                                                            id = '', 
                                                                                                                                            attribute_kind_id = '', 
                                                                                                                                            value = '', 
                                                                                                                                            description = '', 
                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                            participant_attributes = [
                                                                                                                                                keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                                    participant_id = '', 
                                                                                                                                                    attribute_id = '', 
                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                ], )
                                                                                                                                        ], 
                                                                                                                                    attribute_kind_group = keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                                                        id = '', 
                                                                                                                                        name = '', 
                                                                                                                                        description = '', 
                                                                                                                                        scope = 'org', 
                                                                                                                                        purpose = 'screener_response', 
                                                                                                                                        workspace_id = '', 
                                                                                                                                        project_id = '', 
                                                                                                                                        created_by_id = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        attribute_kinds = [
                                                                                                                                            keplar_api.models.attribute_kind.AttributeKind(
                                                                                                                                                id = '', 
                                                                                                                                                key = '', 
                                                                                                                                                label = '', 
                                                                                                                                                value_kind = 'single', 
                                                                                                                                                description = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                attribute_kind_group_id = '', )
                                                                                                                                            ], 
                                                                                                                                        artifacts = [
                                                                                                                                            keplar_api.models.artifact.Artifact(
                                                                                                                                                id = '', 
                                                                                                                                                title = '', 
                                                                                                                                                kind = 'thematic_analysis', 
                                                                                                                                                project_id = '', 
                                                                                                                                                attribute_kind_group_id = '', 
                                                                                                                                                version_group_id = '', 
                                                                                                                                                metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                    status = 'draft', 
                                                                                                                                                    status_message = '', 
                                                                                                                                                    progress = 1.337, 
                                                                                                                                                    description = '', ), 
                                                                                                                                                created_by_id = '', 
                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                version_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                    id = '', 
                                                                                                                                                    project_id = '', 
                                                                                                                                                    kind = 'thematic_analysis', 
                                                                                                                                                    latest_artifact_id = '', 
                                                                                                                                                    latest_artifact = keplar_api.models.artifact.Artifact(
                                                                                                                                                        id = '', 
                                                                                                                                                        title = '', 
                                                                                                                                                        kind = , 
                                                                                                                                                        project_id = '', 
                                                                                                                                                        attribute_kind_group_id = '', 
                                                                                                                                                        version_group_id = '', 
                                                                                                                                                        metadata = keplar_api.models.artifact_metadata.ArtifactMetadata(
                                                                                                                                                            status = 'draft', 
                                                                                                                                                            status_message = '', 
                                                                                                                                                            progress = 1.337, 
                                                                                                                                                            description = '', ), 
                                                                                                                                                        created_by_id = '', 
                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                        latest_for_group = keplar_api.models.artifact_version_group.ArtifactVersionGroup(
                                                                                                                                                            id = '', 
                                                                                                                                                            project_id = '', 
                                                                                                                                                            kind = , 
                                                                                                                                                            latest_artifact_id = '', 
                                                                                                                                                            notebook_artifact_version_groups = [
                                                                                                                                                                keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                                    id = '', 
                                                                                                                                                                    notebook_id = '', 
                                                                                                                                                                    artifact_version_group_id = '', 
                                                                                                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                    notebook = keplar_api.models.notebook.Notebook(
                                                                                                                                                                        id = '', 
                                                                                                                                                                        workspace_id = '', 
                                                                                                                                                                        created_by_id = '', 
                                                                                                                                                                        name = '', 
                                                                                                                                                                        description = '', 
                                                                                                                                                                        config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                                                                                                            sources = [
                                                                                                                                                                                ''
                                                                                                                                                                                ], 
                                                                                                                                                                            mode = 'report', 
                                                                                                                                                                            settings = keplar_api.models.settings.settings(), ), 
                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                        threads = [
                                                                                                                                                                            keplar_api.models.thread.Thread(
                                                                                                                                                                                id = '', 
                                                                                                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                name = '', 
                                                                                                                                                                                description = '', 
                                                                                                                                                                                created_by_id = '', 
                                                                                                                                                                                workspace_id = '', 
                                                                                                                                                                                project_id = '', 
                                                                                                                                                                                notebook_id = '', 
                                                                                                                                                                                thread_files = [
                                                                                                                                                                                    keplar_api.models.thread_file.ThreadFile(
                                                                                                                                                                                        id = '', 
                                                                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                        thread_id = '', 
                                                                                                                                                                                        file_id = '', 
                                                                                                                                                                                        thread = keplar_api.models.thread.Thread(
                                                                                                                                                                                            id = '', 
                                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            name = '', 
                                                                                                                                                                                            description = '', 
                                                                                                                                                                                            created_by_id = '', 
                                                                                                                                                                                            workspace_id = '', 
                                                                                                                                                                                            project_id = '', 
                                                                                                                                                                                            notebook_id = '', ), 
                                                                                                                                                                                        file = keplar_api.models.file.File(
                                                                                                                                                                                            id = '', 
                                                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            filename = '', 
                                                                                                                                                                                            display_name = '', 
                                                                                                                                                                                            mime_type = 'image/jpeg', 
                                                                                                                                                                                            size = '', 
                                                                                                                                                                                            bucket_name = '', 
                                                                                                                                                                                            gcs_path = '', 
                                                                                                                                                                                            gcs_generation = '', 
                                                                                                                                                                                            uploaded_by_id = '', 
                                                                                                                                                                                            workspace_id = '', 
                                                                                                                                                                                            description = '', 
                                                                                                                                                                                            is_public = True, 
                                                                                                                                                                                            expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                                                            public_url = '', 
                                                                                                                                                                                            public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                                                                                                                                                                                    ], )
                                                                                                                                                                            ], ), 
                                                                                                                                                                    artifact_version_group = , )
                                                                                                                                                                ], ), ), 
                                                                                                                                                    notebook_artifact_version_groups = [
                                                                                                                                                        keplar_api.models.notebook_artifact_version_group.NotebookArtifactVersionGroup(
                                                                                                                                                            id = '', 
                                                                                                                                                            notebook_id = '', 
                                                                                                                                                            artifact_version_group_id = '', 
                                                                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                                        ], ), 
                                                                                                                                                latest_for_group = , )
                                                                                                                                            ], ), ), 
                                                                                                                                participant_attributes = [
                                                                                                                                    keplar_api.models.participant_attribute.ParticipantAttribute(
                                                                                                                                        participant_id = '', 
                                                                                                                                        attribute_id = '', 
                                                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                                                                    ], ), )
                                                                                                                        ], )
                                                                                                                ], 
                                                                                                            participant_attributes = , ), 
                                                                                                        conversation_message_topics = [
                                                                                                            keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                                                                                                call_id = '', 
                                                                                                                index = 1.337, 
                                                                                                                description = '', )
                                                                                                            ], )
                                                                                                    ], 
                                                                                                participant_invites = [
                                                                                                    keplar_api.models.participant_invite.ParticipantInvite(
                                                                                                        code = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        participant_id = '', 
                                                                                                        invite_id = '', )
                                                                                                    ], 
                                                                                                invite_responses = [
                                                                                                    
                                                                                                    ], )
                                                                                            ], 
                                                                                        chat_sessions = [
                                                                                            keplar_api.models.chat_session.ChatSession(
                                                                                                id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                created_by_id = '', 
                                                                                                project_id = '', 
                                                                                                chat_messages = [
                                                                                                    keplar_api.models.chat_message.ChatMessage(
                                                                                                        id = '', 
                                                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                        content = '', 
                                                                                                        role = 'user', 
                                                                                                        chat_session_id = '', 
                                                                                                        chat_session = keplar_api.models.chat_session.ChatSession(
                                                                                                            id = '', 
                                                                                                            name = '', 
                                                                                                            description = '', 
                                                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                            created_by_id = '', 
                                                                                                            project_id = '', ), )
                                                                                                    ], )
                                                                                            ], 
                                                                                        threads = [
                                                                                            
                                                                                            ], 
                                                                                        attribute_kind_group = [
                                                                                            keplar_api.models.attribute_kind_group.AttributeKindGroup(
                                                                                                id = '', 
                                                                                                name = '', 
                                                                                                description = '', 
                                                                                                scope = 'org', 
                                                                                                purpose = 'screener_response', 
                                                                                                workspace_id = '', 
                                                                                                project_id = '', 
                                                                                                created_by_id = '', 
                                                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                                            ], 
                                                                                        artifacts = [
                                                                                            
                                                                                            ], 
                                                                                        artifact_version_group = [
                                                                                            
                                                                                            ], ), 
                                                                                    file = , )
                                                                                ], 
                                                                            thread_files = [
                                                                                keplar_api.models.thread_file.ThreadFile(
                                                                                    id = '', 
                                                                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                                    thread_id = '', 
                                                                                    file_id = '', )
                                                                                ], )
                                                                        ], 
                                                                    threads = , 
                                                                    attribute_kind_groups = [
                                                                        
                                                                        ], 
                                                                    workspace_members = [
                                                                        keplar_api.models.workspace_member.WorkspaceMember(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            role = 'owner', 
                                                                            user_id = '', 
                                                                            workspace_id = '', 
                                                                            user = , )
                                                                        ], 
                                                                    notebooks = [
                                                                        keplar_api.models.notebook.Notebook(
                                                                            id = '', 
                                                                            workspace_id = '', 
                                                                            created_by_id = '', 
                                                                            name = '', 
                                                                            description = '', 
                                                                            config = keplar_api.models.notebook_config.NotebookConfig(
                                                                                sources = [
                                                                                    ''
                                                                                    ], 
                                                                                mode = 'report', 
                                                                                settings = keplar_api.models.settings.settings(), ), 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                                                        ], 
                                                                    default_for_users = [
                                                                        
                                                                        ], 
                                                                    default_for_orgs = [
                                                                        keplar_api.models.org.Org(
                                                                            id = '', 
                                                                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                            name = '', 
                                                                            domain = '', 
                                                                            default_workspace_id = '', )
                                                                        ], ), 
                                                                moderator = , 
                                                                invites = [
                                                                    
                                                                    ], 
                                                                chat_sessions = [
                                                                    
                                                                    ], 
                                                                project_files = [
                                                                    keplar_api.models.project_file.ProjectFile(
                                                                        id = '', 
                                                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                        project_id = '', 
                                                                        file_id = '', 
                                                                        description = '', )
                                                                    ], 
                                                                threads = , 
                                                                attribute_kind_group = [
                                                                    
                                                                    ], 
                                                                artifacts = , 
                                                                artifact_version_group = [
                                                                    
                                                                    ], )
                                                            ], 
                                                        participants = [
                                                            keplar_api.models.participant.Participant(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                email = '', 
                                                                phone_number = '', 
                                                                name = '', 
                                                                workspace_id = '', )
                                                            ], 
                                                        moderators = [
                                                            
                                                            ], 
                                                        files = [
                                                            
                                                            ], 
                                                        threads = , 
                                                        attribute_kind_groups = [
                                                            
                                                            ], 
                                                        workspace_members = [
                                                            keplar_api.models.workspace_member.WorkspaceMember(
                                                                id = '', 
                                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                                role = 'owner', 
                                                                user_id = '', 
                                                                workspace_id = '', )
                                                            ], 
                                                        notebooks = [
                                                            
                                                            ], 
                                                        default_for_users = [
                                                            
                                                            ], 
                                                        default_for_orgs = [
                                                            
                                                            ], ), 
                                                    workspace_members = , 
                                                    projects = [
                                                        
                                                        ], 
                                                    invites = , 
                                                    chat_sessions = , 
                                                    moderators = , 
                                                    uploaded_files = [
                                                        
                                                        ], 
                                                    threads = , 
                                                    attribute_kind_group = , 
                                                    artifact = [
                                                        
                                                        ], 
                                                    notebooks = , )
                                                ], 
                                            default_workspace = , ), 
                                        default_workspace = , 
                                        workspace_members = , 
                                        projects = , 
                                        invites = , 
                                        chat_sessions = , 
                                        moderators = , 
                                        uploaded_files = [
                                            
                                            ], 
                                        threads = , 
                                        attribute_kind_group = , 
                                        artifact = [
                                            
                                            ], 
                                        notebooks = , ), 
                                    project = , 
                                    calls = [
                                        
                                        ], 
                                    participant_invites = , 
                                    invite_responses = , ), 
                                participant = , 
                                calls = , 
                                invite_response_attributes = [
                                    keplar_api.models.invite_response_attribute.InviteResponseAttribute(
                                        invite_response_id = '', 
                                        attribute_id = '', 
                                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                    ], ), 
                            events = [
                                keplar_api.models.call_event.CallEvent(
                                    call_id = '', 
                                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    kind = '', 
                                    data = keplar_api.models.call_event_data.CallEventData(), )
                                ], 
                            participant = , 
                            invite = , 
                            conversation_message_topics = [
                                keplar_api.models.conversation_message_topic.ConversationMessageTopic(
                                    call_id = '', 
                                    index = 1.337, 
                                    description = '', )
                                ], ), 
                        conversation_message_topic = , )
                    ]
            )
        else:
            return ConversationMessageTopic(
                call_id = '',
                index = 1.337,
                description = '',
        )
        """

    def testConversationMessageTopic(self):
        """Test ConversationMessageTopic"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
